aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2020-07-02 09:07:58 +0200
committerSven Gothel <[email protected]>2020-07-02 09:07:58 +0200
commit5f43b2454eac3ed762f2576ad8e549c26200661c (patch)
tree8ba4b41426254bb18a08c7e278de27240a76b61e
parent5274ba17c0fc06d79e53b20d00149a7ce068dd1f (diff)
GATTHandler: Initial GATT reply may even require ~2s, setting timeout to 2500ms.v2.1.10
See commit 6f67d72923b31dd5db32227a0a8f46c11bc9a9f3
-rw-r--r--api/direct_bt/GATTHandler.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/api/direct_bt/GATTHandler.hpp b/api/direct_bt/GATTHandler.hpp
index f15f3b16..99d5d7ad 100644
--- a/api/direct_bt/GATTHandler.hpp
+++ b/api/direct_bt/GATTHandler.hpp
@@ -75,8 +75,8 @@ namespace direct_bt {
L2CAP_READER_THREAD_POLL_TIMEOUT = 3000,
/** 500ms timeout for l2cap command replies */
L2CAP_COMMAND_REPLY_TIMEOUT = 500,
- /** 1500ms timeout for l2cap _initial_ command reply, long timeout. */
- L2CAP_INITIAL_COMMAND_REPLY_TIMEOUT = 1500,
+ /** 2500ms timeout for l2cap _initial_ command reply, long timeout. */
+ L2CAP_INITIAL_COMMAND_REPLY_TIMEOUT = 2500,
/** Medium ringbuffer capacity... */
ATTPDU_RING_CAPACITY = 128